==> mdpusher_flutter_t-0.1.4.tar.gz: lib/mdpusher_flutter.dart <==
import 'dart:async';
import 'package:flutter/material.dart';
import 'package:flutter/services.dart';
import 'package:mdpusher_plugin/mdpusher_plugin.dart';

class MDLiveBuilder {
  final MDLiveConfig _config;
  MDLiveBuilder(this._config);

  void presentLivePage(BuildContext context) {
    Navigator.push(context, MaterialPageRoute(builder: (BuildContext cnt) {
      return _MDLivePage(_config);
    }));
  }
}

class MDLiveConfig {
  bool _isPortrait;
  bool _frontCamera;
  bool _flashLightOn = false;
  bool _beautyOn;
  bool _micOn;
  int _frameRate;
  int _bitrate;
  MDResolution _resolution;
  String _url;

  MDLiveConfig({
    @required String url,
    bool isPortrait,
    bool frontCamera,
    bool beautyOn,
    bool micOn,
    int frameRate,
    int bitrate,
    MDResolution resolution
  }){
    assert(url != null);
    _url = url;
    _isPortrait = isPortrait;
    _frontCamera = frontCamera;
    _beautyOn = beautyOn;
    _flashLightOn = flashLightOn;
    _micOn = micOn;
    _frameRate = frameRate;
    _bitrate = bitrate;
    _resolution = resolution;
    if (isPortrait == null) {
      _isPortrait = false;
    }
    if (frontCamera == null) {
      _frontCamera = true;
    }
    if (beautyOn == null) {
      _beautyOn = true;
    }
    if (micOn == null) {
      _micOn = true;
    }
    if (bitrate == null) {
      _bitrate = 500;
    }
    if (frameRate == null) {
      _frameRate = 25;
    }
    if (resolution == null) {
      _resolution = MDResolution.Preset960x540;
    }
  }

  String get url {
    return _url;
  }

  bool get isPortrait {
    return _isPortrait;
  }

  bool get frontCamera {
    return _frontCamera;
  }

  bool get flashLightOn {
    return _flashLightOn;
  }

  bool get beautyOn {
    return _beautyOn;
  }

  bool get micOn {
    return _micOn;
  }

  int get frameRate {
    return _frameRate;
  }

  int get bitrate {
    return _bitrate;
  }

  MDResolution get resolution {
    return _resolution;
  }
}

class _MDLivePage extends StatefulWidget {
  final MDLiveConfig _config;
  _MDLivePage(this._config);

  @override
  State<StatefulWidget> createState() {
    return _MDLivePageState();
  }
}

class _MDLivePageState extends State<_MDLivePage> {

  MdpusherPlugin _mdpusherPlugin;
  Container _container;
  Widget _nativeView;
  bool _hide = true;

  bool _isPushing = false;

  Timer _toastTimer;
  bool _shouldShowToast = false;
  String _toastMessage;

  @override
  void initState() {
    initViews();

    super.initState();

    SystemChrome.setEnabledSystemUIOverlays([]);
  }

  @override
  Widget build(BuildContext context) {
    return Scaffold(
      body: Container(
        child: _createLiveView(widget._config),
      ),
    );
  }

  void initViews() async {
    if (widget._config._isPortrait){
      await MdpusherPlugin.setOrientation(MDOrientation.OrientationPortrait);
    }else{
      await MdpusherPlugin.setOrientation(MDOrientation.OrientationLandscapeRight);
    }

    _mdpusherPlugin = MdpusherPlugin(
        isPortrait: widget._config._isPortrait,
        frontCamera: widget._config._frontCamera,
        beautyOn: widget._config._beautyOn,
        micOn: widget._config._micOn,
        bitrate: widget._config._bitrate,
        frameRate: widget._config._frameRate,
        resolution: widget._config._resolution
    );

    _mdpusherPlugin.setCallback(
        onPushStarted: () {
          _showToast('推流成功');
          setState(() {
            _isPushing = true;
          });
        },
        onPushStoped: () {
          _showToast('推流停止');
          setState(() {
            _isPushing = false;
          });
        },
        onReconnectStart: () {
          _showToast('开始重连');
        },
        onReconnectFail: () {
          _showToast('重连失败');
          setState(() {
            _isPushing = false;
          });
        },
        onReconnectSucceed: () {
          _showToast('重连成功');
          setState(() {
            _isPushing = true;
          });
        },
        onConnectionLost: () {
          _showToast('连接丢失');
          setState(() {
            _isPushing = false;
          });
        },
        onConnectFail: () {
          _showToast('连接失败');
          setState(() {
            _isPushing = false;
          });
        },
        onSystemError: () {
          _showToast('系统错误');
        },
        onSDKError: () {
          _showToast('SDK错误');
          setState(() {
            _isPushing = false;
          });
        }
    );

    setState(() {
      _nativeView = MdpusherPlugin.createNativeView((int viewId) {
        _mdpusherPlugin.startPreview(viewId);
      });
      _container = Container(child: _nativeView,);
    });
  }

  Widget _createLiveView(MDLiveConfig config) {
    return Stack(
        children: <Widget>[
          _container != null?_container:Container(),
          Container(
            child: GestureDetector(
              onTap: () {
                setState(() {
                  _hide = !_hide;
                });
              },
            ),
          ),
          SafeArea(child: Offstage(
            offstage: _hide,
            child: Row(
              mainAxisAlignment: MainAxisAlignment.spaceEvenly,
              children: _getLiveToolWidgets(),
            ),
          )),
          SafeArea(child:Align(
            alignment: widget._config._isPortrait?Alignment(0, 1):Alignment(0.9, 0),
            child: GestureDetector(
              child: Image(image: AssetImage(_isPushing?'packages/mdpusher_flutter_t/images/Start_s.png':'packages/mdpusher_flutter_t/images/Start.png'),),
              onTap: () {
                if (_isPushing) {
                  _mdpusherPlugin.stopPush();
                } else {
                  _showToast('开始推流');
                  _mdpusherPlugin.startPushAsync(widget._config._url);
                }
              },
            ),
          ), ),
          SafeArea(child: Offstage(
            offstage: _hide,
            child: Align(
              alignment: Alignment(0.9, 1),
              child: widget._config._isPortrait?
              GestureDetector(
                child: Image(image: AssetImage('packages/mdpusher_flutter_t/images/Setting.png')),
                onTap: () {
                  _closeAction(context);
                },
              ):
              Container(),
            ),
          )),
          _createToast(),
        ]
    );
  }

  List<Widget> _getLiveToolWidgets() {
    List<Widget> widgets = List();
    MDLiveConfig config = widget._config;
    widgets.add(GestureDetector(
      child: Image(image: AssetImage('packages/mdpusher_flutter_t/images/SwitchCamera.png')),
      onTap: _switchCamera,
    ));
    widgets.add(GestureDetector(
      child: Image(image: AssetImage(config._beautyOn?'packages/mdpusher_flutter_t/images/BeautyOn.png':'packages/mdpusher_flutter_t/images/BeautyOff.png')),
      onTap: _switchBeauty,
    ));
    widgets.add(GestureDetector(
      child: Image(image: AssetImage(config._flashLightOn?'packages/mdpusher_flutter_t/images/FlashLight_on.png':'packages/mdpusher_flutter_t/images/FlashLight_off.png')),
      onTap: _switchFlashLight,
    ));
    widgets.add(GestureDetector(
      child: Image(image: AssetImage(config._micOn?'packages/mdpusher_flutter_t/images/SwitchMic_on.png':'packages/mdpusher_flutter_t/images/SwitchMic_off.png')),
      onTap: _switchMicrophone,
    ));
    if (!widget._config.isPortrait) {
      widgets.add(GestureDetector(
        child: Image(image: AssetImage('packages/mdpusher_flutter_t/images/Setting.png')),
        onTap: () {
          _closeAction(context);
        },
      ));
    }
    return widgets;
  }

  void _switchCamera() {
    if (!widget._config.frontCamera && widget._config._flashLightOn) {
      _switchFlashLight();
    }
    _mdpusherPlugin.switchCamera();
    setState(() {
      widget._config._frontCamera = !widget._config._frontCamera;
    });
  }

  void _switchBeauty() {
    _mdpusherPlugin.setBeautyOn(!widget._config._beautyOn);
    setState(() {
      widget._config._beautyOn = !widget._config._beautyOn;
    });
  }

  void _switchFlashLight() {
    if (widget._config._frontCamera) {
      return;
    }
    _mdpusherPlugin.setFlashLight(!widget._config._flashLightOn);
    setState(() {
      widget._config._flashLightOn = !widget._config._flashLightOn;
    });
  }

  void _switchMicrophone() {
    _mdpusherPlugin.setMicOn(!widget._config._micOn);
    setState(() {
      widget._config._micOn = !widget._config._micOn;
    });
  }

  void _closeAction(BuildContext context) {
    _mdpusherPlugin.destory();
    Navigator.pop(context);
  }

  Widget _createToast() {
    if (_shouldShowToast) {
      return Center(
        key: ValueKey('toast'),
        child: Container(
          color: Color.fromRGBO(0, 0, 0, 0.3),
          padding: EdgeInsets.fromLTRB(5, 2, 5, 2),
          child: Text(_toastMessage,
            style: TextStyle(
                fontSize: 13,
                color: Colors.white
            ),
          ),
        ),
      );
    } else {
      return Container();
    }
  }

  void _showToast(String msg) {
    if (_toastTimer != null && _toastTimer.isActive) {
      _toastTimer.cancel();
    }
    setState(() {
      _shouldShowToast = true;
      _toastMessage = msg;
    });
    _toastTimer = new Timer(Duration(seconds: 3), () {
      setState(() {
        _shouldShowToast = false;
      });
    });
  }

  @override
  void dispose() {
    _mdpusherPlugin.destory();
    MdpusherPlugin.setOrientation(null);
    SystemChrome.setEnabledSystemUIOverlays([SystemUiOverlay.top]);
    if (_toastTimer != null && _toastTimer.isActive) {
      _toastTimer.cancel();
    }
    super.dispose();
  }
}

==> mdpusher_flutter_t-0.2.1.tar.gz: lib/mdpusher_flutter.dart <==
import 'dart:async';
import 'dart:ui';
import 'package:flutter/material.dart';
import 'package:flutter/services.dart';
import 'package:mdpusher_plugin/mdpusher_plugin.dart';

class MDLiveBuilder {
  final MDLiveConfig _config;
  MDLiveBuilder(this._config);

  void presentLivePage(BuildContext context) {
    Navigator.push(context, MaterialPageRoute(builder: (BuildContext cnt) {
      return _MDLivePage(_config);
    }));
  }
}

class MDLiveConfig {
  bool _isPortrait;
  bool _frontCamera;
  bool _flashLightOn = false;
  bool _beautyOn;
  bool _micOn;
  int _frameRate;
  int _bitrate;
  MDResolution _resolution;
  String _url;

  MDLiveConfig({
    @required String url,
    bool isPortrait,
    bool frontCamera,
    bool beautyOn,
    bool micOn,
    int frameRate,
    int bitrate,
    MDResolution resolution
  }){
    assert(url != null);
    _url = url;
    _isPortrait = isPortrait;
    _frontCamera = frontCamera;
    _beautyOn = beautyOn;
    _flashLightOn = flashLightOn;
    _micOn = micOn;
    _frameRate = frameRate;
    _bitrate = bitrate;
    _resolution = resolution;
    if (isPortrait == null) {
      _isPortrait = false;
    }
    if (frontCamera == null) {
      _frontCamera = true;
    }
    if (beautyOn == null) {
      _beautyOn = true;
    }
    if (micOn == null) {
      _micOn = true;
    }
    if (bitrate == null) {
      _bitrate = 500;
    }
    if (frameRate == null) {
      _frameRate = 25;
    }
    if (resolution == null) {
      _resolution = MDResolution.Preset960x540;
    }
  }

  String get url {
    return _url;
  }

  bool get isPortrait {
    return _isPortrait;
  }

  bool get frontCamera {
    return _frontCamera;
  }

  bool get flashLightOn {
    return _flashLightOn;
  }

  bool get beautyOn {
    return _beautyOn;
  }

  bool get micOn {
    return _micOn;
  }

  int get frameRate {
    return _frameRate;
  }

  int get bitrate {
    return _bitrate;
  }

  MDResolution get resolution {
    return _resolution;
  }
}

class _MDLivePage extends StatefulWidget {
  final MDLiveConfig _config;
  _MDLivePage(this._config);

  @override
  State<StatefulWidget> createState() {
    return _MDLivePageState();
  }
}

class _MDLivePageState extends State<_MDLivePage> with TickerProviderStateMixin {

  MdpusherPlugin _mdpusherPlugin;
  Container _container;
  Widget _nativeView;
  bool _hide = true;

  bool _isPushing = false;

  Timer _toastTimer;
  bool _shouldShowToast = false;
  String _toastMessage;

  AnimationController _animationController;
  Animation<double> _animation;
  double _lastAnimationY;

  double _showY;
  double _hideY;

  @override
  void initState() {
    initViews();

    super.initState();

    SystemChrome.setEnabledSystemUIOverlays([]);
  }

  @override
  Widget build(BuildContext context) {
    return Scaffold(
      body: Container(
        child: _createLiveView(widget._config),
      ),
    );
  }

  void initViews() async {
    if (widget._config._isPortrait){
      await MdpusherPlugin.setOrientation(MDOrientation.OrientationPortrait);
    }else{
      await MdpusherPlugin.setOrientation(MDOrientation.OrientationLandscapeRight);
    }

    _showY = convertLogicalYToTextureY(10);
    _hideY = convertLogicalYToTextureY(-38);

    _mdpusherPlugin = MdpusherPlugin(
        isPortrait: widget._config._isPortrait,
        frontCamera: widget._config._frontCamera,
        beautyOn: widget._config._beautyOn,
        micOn: widget._config._micOn,
        bitrate: widget._config._bitrate,
        frameRate: widget._config._frameRate,
        resolution: widget._config._resolution
    );

    _mdpusherPlugin.setCallback(
        onPushStarted: () {
          _showToast('推流成功');
          setState(() {
            _isPushing = true;
          });
        },
        onPushStoped: () {
          _showToast('推流停止');
          setState(() {
            _isPushing = false;
          });
        },
        onReconnectStart: () {
          _showToast('开始重连');
        },
        onReconnectFail: () {
          _showToast('重连失败');
          setState(() {
            _isPushing = false;
          });
        },
        onReconnectSucceed: () {
          _showToast('重连成功');
          setState(() {
            _isPushing = true;
          });
        },
        onConnectionLost: () {
          _showToast('连接丢失');
          setState(() {
            _isPushing = false;
          });
        },
        onConnectFail: () {
          _showToast('连接失败');
          setState(() {
            _isPushing = false;
          });
        },
        onSystemError: () {
          _showToast('系统错误');
        },
        onSDKError: () {
          _showToast('SDK错误');
          setState(() {
            _isPushing = false;
          });
        }
    );

    setState(() {
      _nativeView = MdpusherPlugin.createNativeView((int viewId) {
        _mdpusherPlugin.startPreview(viewId);
      });
      _container = Container(child: _nativeView,);
    });
  }

  Widget _createLiveView(MDLiveConfig config) {

    return Stack(
        children: <Widget>[
          _container != null?_container:Container(),
          Container(
            child: GestureDetector(
              onTap: () {
                setState(() {
                  _hide = !_hide;

                  if (_animationController != null && _animationController.isAnimating) {
                    _lastAnimationY = _animation.value;
                    _animationController.dispose();
                  }
                  _animationController = AnimationController(vsync: this, duration: Duration(milliseconds: 250));
                  double startY;
                  double endY;
                  if (_hide) {
                    startY = _lastAnimationY != null ? _lastAnimationY : _showY;
                    endY = _hideY;
                  } else {
                    startY = _lastAnimationY != null ? _lastAnimationY : _hideY;
                    endY = _showY;
                  }

                  _animation = Tween(begin: startY,end: endY).animate(_animationController)..addListener(() {
                    setState(() {
                    });
                  })..addStatusListener((AnimationStatus status) {
                    if (status == AnimationStatus.completed) {
                      _animationController.dispose();
                      _animationController = null;
                      _lastAnimationY = null;
                    }
                  });

                  _animationController.forward();
                });
              },
            ),
          ),
          SafeArea(child: Align(
              alignment: Alignment(-1, _animation != null? _animation.value : -_hideY),
              child: Row(
                  mainAxisAlignment: MainAxisAlignment.spaceEvenly,
                  children: _getLiveToolWidgets()
              )
          )),
          SafeArea(child:Align(
            alignment: widget._config._isPortrait?Alignment(0, 0.95):Alignment(0.9, 0),
            child: GestureDetector(
              child: Image(image: AssetImage(_isPushing?'packages/mdpusher_flutter_t/images/Start_s.png':'packages/mdpusher_flutter_t/images/Start.png'),),
              onTap: () {
                if (_isPushing) {
                  _mdpusherPlugin.stopPush();
                } else {
                  _showToast('开始推流');
                  _mdpusherPlugin.startPushAsync(widget._config._url);
                }
              },
            ),
          ), ),
          SafeArea(child: Align(
            alignment: Alignment(0.9, _animation != null ? -_animation.value : -_hideY),
            child: widget._config._isPortrait?
            GestureDetector(
              child: Image(image: AssetImage('packages/mdpusher_flutter_t/images/Setting.png')),
              onTap: () {
                _closeAction(context);
              },
            ):
            Container(),
          )),
          _createToast(),
        ]
    );
  }

  List<Widget> _getLiveToolWidgets() {
    List<Widget> widgets = List();
    MDLiveConfig config = widget._config;
    widgets.add(GestureDetector(
      child: Image(image: AssetImage('packages/mdpusher_flutter_t/images/SwitchCamera.png'), width: 28, height: 28,),
      onTap: _switchCamera,
    ));
    widgets.add(GestureDetector(
      child: Image(image: AssetImage(config._beautyOn?'packages/mdpusher_flutter_t/images/BeautyOn.png':'packages/mdpusher_flutter_t/images/BeautyOff.png'), width: 28, height: 28,),
      onTap: _switchBeauty,
    ));
    widgets.add(GestureDetector(
      child: Image(image: AssetImage(config._flashLightOn?'packages/mdpusher_flutter_t/images/FlashLight_on.png':'packages/mdpusher_flutter_t/images/FlashLight_off.png'), width: 28, height: 28,),
      onTap: _switchFlashLight,
    ));
    widgets.add(GestureDetector(
      child: Image(image: AssetImage(config._micOn?'packages/mdpusher_flutter_t/images/SwitchMic_on.png':'packages/mdpusher_flutter_t/images/SwitchMic_off.png'), width: 28, height: 28,),
      onTap: _switchMicrophone,
    ));
    if (!widget._config.isPortrait) {
      widgets.add(GestureDetector(
        child: Image(image: AssetImage('packages/mdpusher_flutter_t/images/Setting.png'), width: 28, height: 28,),
        onTap: () {
          _closeAction(context);
        },
      ));
    }
    return widgets;
  }

  void _switchCamera() {
    if (!widget._config.frontCamera && widget._config._flashLightOn) {
      _switchFlashLight();
    }
    _mdpusherPlugin.switchCamera();
    setState(() {
      widget._config._frontCamera = !widget._config._frontCamera;
    });
  }

  void _switchBeauty() {
    _mdpusherPlugin.setBeautyOn(!widget._config._beautyOn);
    setState(() {
      widget._config._beautyOn = !widget._config._beautyOn;
    });
  }

  void _switchFlashLight() {
    if (widget._config._frontCamera) {
      return;
    }
    _mdpusherPlugin.setFlashLight(!widget._config._flashLightOn);
    setState(() {
      widget._config._flashLightOn = !widget._config._flashLightOn;
    });
  }

  void _switchMicrophone() {
    _mdpusherPlugin.setMicOn(!widget._config._micOn);
    setState(() {
      widget._config._micOn = !widget._config._micOn;
    });
  }

  void _closeAction(BuildContext context) {
    _mdpusherPlugin.destory();
    Navigator.pop(context);
  }

  Widget _createToast() {
    if (_shouldShowToast) {
      return Center(
        key: ValueKey('toast'),
        child: Container(
          color: Color.fromRGBO(0, 0, 0, 0.3),
          padding: EdgeInsets.fromLTRB(5, 2, 5, 2),
          child: Text(_toastMessage,
            style: TextStyle(
                fontSize: 13,
                color: Colors.white
            ),
          ),
        ),
      );
    } else {
      return Container();
    }
  }

  void _showToast(String msg) {
    if (_toastTimer != null && _toastTimer.isActive) {
      _toastTimer.cancel();
    }
    setState(() {
      _shouldShowToast = true;
      _toastMessage = msg;
    });
    _toastTimer = new Timer(Duration(seconds: 3), () {
      setState(() {
        _shouldShowToast = false;
      });
    });
  }

  @override
  void dispose() {
    _mdpusherPlugin.destory();
    MdpusherPlugin.setOrientation(null);
    SystemChrome.setEnabledSystemUIOverlays([SystemUiOverlay.top]);
    if (_toastTimer != null && _toastTimer.isActive) {
      _toastTimer.cancel();
    }
    super.dispose();
  }

  double convertLogicalYToTextureY(int y) {
    Size physicalSize = window.physicalSize;
    double pixelRatio = window.devicePixelRatio;
    double logicalHeight = widget._config._isPortrait?physicalSize.height / pixelRatio:physicalSize.width / pixelRatio;
    double percent = y / logicalHeight;
    double textureY = percent * 2 - 1;
    return textureY;
  }
}
